@@ -315,7 +315,7 @@ class HardwareConfig(models.Model):
 
 class ChannelStats(models.Model):
     def get_name_display(self):
-        name = self.channel.nickname + ' / ' + self.type
+        name = self.channel.get_name_display() + ' / ' + self.type
         return name
 
     id = models.UUIDField(primary_key=True, default=uuid.uuid4)
