@@ -43,13 +43,9 @@ class ChannelStatsSerializer(serializers.ModelSerializer):
         fields = ['id', 'channel', 'type', 'value','model']
 
 class ChannelSerializer(serializers.ModelSerializer):
-    channelstats_set = ChannelStatsSerializer(read_only=True,many=True)
+    channelstats_set = ChannelStatsSerializer(read_only=True,many=True, required=False)
     model = serializers.SerializerMethodField()
 
-    def restore_object(self, attrs, instance=None):
-        instance = super(ChannelSerializer, self).restore_object(attrs, instance)
-        instance.channelstats = ChannelStats.objects.get({'channel':instance.id}).all
-        return instance
 
     def get_model(self, instance):
         try:
